@@ -4,7 +4,7 @@ package WebService::Avalara::AvaTax;
 
 use Modern::Perl '2011';    ## no critic (Modules::ProhibitUseQuotedVersion)
 
-our $VERSION = '0.010';     # VERSION
+our $VERSION = '0.011';     # VERSION
 use utf8;
 
 #pod =head1 SYNOPSIS
@@ -142,7 +142,8 @@ sub _new_service {
 #pod
 #pod SOAP operation names have been transformed from C<CamelCase> to
 #pod C<lowercase_with_underscores>. For example, C<GetTax> is now
-#pod L</get_tax>.
+#pod L</get_tax>. If you do not like this behavior then use
+#pod C<< L</orthodox> => 1 >> when calling L</new>.
 #pod
 #pod =item *
 #pod
@@ -166,6 +167,15 @@ sub _new_service {
 #pod
 #pod =back
 #pod
+#pod =attr orthodox
+#pod
+#pod When set to true at construction, the generated methods will exactly match
+#pod their C<CamelCase> SOAP operation names.
+#pod
+#pod =cut
+
+has orthodox => ( is => 'ro', isa => Bool, default => 0 );
+
 #pod =for Pod::Coverage BUILD
 #pod
 #pod =cut
@@ -184,8 +194,11 @@ sub BUILD {
 
             # normalize operation name into a Perl method name
             my $method_name = $operation->name;
-            $method_name =~ s/ (?<= [[:alnum:]] ) ( [[:upper:]] ) /_\l$1/xmsg;
-            $method_name = lcfirst $method_name;
+            if ( not $self->orthodox ) {
+                $method_name
+                    =~ s/ (?<= [[:alnum:]] ) ( [[:upper:]] ) /_\l$1/xmsg;
+                $method_name = lcfirst $method_name;
+            }
 
             $self->_stash->add_symbol(
                 "&$method_name" => _method_closure( $service, $operation ) );
@@ -268,7 +281,7 @@ WebService::Avalara::AvaTax - Avalara SOAP interface as compiled Perl methods
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -316,7 +329,8 @@ and more Perl-ish, the following changes have been made:
 
 SOAP operation names have been transformed from C<CamelCase> to
 C<lowercase_with_underscores>. For example, C<GetTax> is now
-L</get_tax>.
+L</get_tax>. If you do not like this behavior then use
+C<< L</orthodox> => 1 >> when calling L</new>.
 
 =item *
 
@@ -349,6 +363,8 @@ that can be set at construction.
 
 =head2 get_tax
 
+I<< (SOAP operation: C<GetTax>) >>
+
 Constructing and making an example request:
 
     my %get_tax_request = (
@@ -440,6 +456,8 @@ Constructing and making an example request:
 
 =head2 post_tax
 
+I<< (SOAP operation: C<PostTax>) >>
+
 Example:
 
     my ( $answer_ref, $trace ) = $avatax->post_tax(
@@ -455,6 +473,8 @@ Example:
 
 =head2 commit_tax
 
+I<< (SOAP operation: C<CommitTax>) >>
+
 Example:
 
     my ( $answer_ref, $trace ) = $avatax->commit_tax(
@@ -466,6 +486,8 @@ Example:
 
 =head2 cancel_tax
 
+I<< (SOAP operation: C<CommitTax>) >>
+
 Example:
 
     my ( $answer_ref, $trace ) = $avatax->cancel_tax(
@@ -477,6 +499,8 @@ Example:
 
 =head2 adjust_tax
 
+I<< (SOAP operation: C<AdjustTax>) >>
+
 Example:
 
     my ( $answer_ref, $trace ) = $avatax->adjust_tax(
@@ -576,6 +600,8 @@ Example:
 
 =head2 get_tax_history
 
+I<< (SOAP operation: C<GetTaxHistory>) >>
+
 Example:
 
     my ( $answer_ref, $trace ) = $avatax->get_tax_history(
@@ -587,6 +613,8 @@ Example:
 
 =head2 validate
 
+I<< (SOAP operation: C<Validate>) >>
+
 Example:
 
     my ( $answer_ref, $trace ) = $avatax->validate(
@@ -605,6 +633,8 @@ Example:
 
 =head2 is_authorized
 
+I<< (SOAP operation: C<IsAuthorized>) >>
+
 Both
 L<WebService::Avalara::AvaTax::Service::Address|WebService::Avalara::AvaTax::Service::Address>
 and
@@ -617,6 +647,9 @@ method on its
 L<wsdl|WebService::Avalara::AvaTax::Role::Connection/wsdl>
 attribute.
 
+Note that the parameter passed to this call is a comma-delimited list of
+SOAP operation names in C<CamelCase>, not C<lowercase_with_underscores>.
+
 Example:
 
     my ( $answer_ref, $trace ) = $avatax->is_authorized(
@@ -634,6 +667,8 @@ Example:
 
 =head2 ping
 
+I<< (SOAP operation: C<Ping>) >>
+
 Both
 L<WebService::Avalara::AvaTax::Service::Address|WebService::Avalara::AvaTax::Service::Address>
 and
@@ -646,6 +681,9 @@ method on its
 L<wsdl|WebService::Avalara::AvaTax::Role::Connection/wsdl>
 attribute.
 
+Note that this method does support a single string as a message parameter;
+this is effectively ignored though.
+
 Example:
 
     use List::Util 1.33 'any';
@@ -659,6 +697,8 @@ Example:
 
 =head2 tax_summary_fetch
 
+I<< (SOAP operation: C<TaxSummaryFetch>) >>
+
 Example:
 
     my ( $answer_ref, $trace ) = $avatax->tax_summary_fetch(
@@ -669,6 +709,8 @@ Example:
 
 =head2 apply_payment (DEPRECATED)
 
+I<< (SOAP operation: C<ApplyPayment>) >>
+
 From L<Avalara API documentation|http://developer.avalara.com/api-docs/soap/applypayment>:
 
 =over
@@ -693,6 +735,8 @@ Example:
 
 =head2 reconcile_tax_history (LEGACY API)
 
+I<< (SOAP operation: C<ReconcileTaxHistory>) >>
+
 From L<Avalara API documentation|http://developer.avalara.com/api-docs/soap/reconciletaxhistory>:
 
 =over
@@ -749,6 +793,11 @@ passed to both:
 
 =back
 
+=head2 orthodox
+
+When set to true at construction, the generated methods will exactly match
+their C<CamelCase> SOAP operation names.
+
 =head1 SEE ALSO
 
 =over
